# Docker

## Run neurodiffeq inside a docker container
`sh ./docker/docker-shell.sh`

## For Windows user

`docker-shell.bat`

**To open a jupyter notebook in the container, execute the command  `notebook`**

**For people working in windows, and using VScode set your default newline as LF instead of CRLF.**

**This can be done by clicking on the CRLF option at the bottom right of the editor window and choosing LF in the generated menu.**

**For any other Windows related issues refer to the document "Docker_for_Windows.pdf"**